@@ -1,4 +1,18 @@
-// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
+/*
+ * Copyright 2000-2020 JetBrains s.r.o.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * https://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 package org.jetbrains.annotations;
 
 import java.lang.annotation.ElementType;
@@ -12,7 +26,7 @@ import java.lang.annotation.Target;
  *
  * @author egor
  */
-public interface Async {
+public final class Async {
 
   /**
    * Indicates that the marked method schedules async computation.
@@ -20,7 +34,7 @@ public interface Async {
    */
   @Retention(RetentionPolicy.CLASS)
   @Target({ElementType.METHOD, ElementType.CONSTRUCTOR, ElementType.PARAMETER})
-  @interface Schedule {}
+  public @interface Schedule {}
 
   /**
    * Indicates that the marked method executes async computation.
@@ -29,5 +43,5 @@ public interface Async {
    */
   @Retention(RetentionPolicy.CLASS)
   @Target({ElementType.METHOD, ElementType.CONSTRUCTOR, ElementType.PARAMETER})
-  @interface Execute {}
+  public @interface Execute {}
 }
