@@ -1,11 +1,11 @@
 /*
- * Copyright 2000-2015 JetBrains s.r.o.
+ * Copyright 2000-2020 JetBrains s.r.o.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,12 +18,17 @@ package org.jetbrains.annotations;
 import java.lang.annotation.*;
 
 /**
- * A method/constructor annotated with TestOnly claims that it should be called from testing code only.
+ * A member or type annotated with TestOnly claims that it should be used from testing code only.
  * <p>
  * Apart from documentation purposes this annotation is intended to be used by static analysis tools
  * to validate against element contract violations.
+ * <p>
+ * This annotation means that the annotated element exposes internal data and breaks encapsulation 
+ * of the containing class; the annotation won't prevent its use from production code, developers 
+ * even won't see warnings if their IDE doesn't support the annotation. It's better to provide 
+ * proper API which can be used in production as well as in tests.
  */
 @Documented
-@Retention(RetentionPolicy.SOURCE)
+@Retention(RetentionPolicy.CLASS)
 @Target({ElementType.METHOD, ElementType.CONSTRUCTOR, ElementType.FIELD, ElementType.TYPE})
 public @interface TestOnly { }
\ No newline at end of file
